==> resample_plugin-0.0.1.tar.gz: lib/resample_plugin.dart <==

import 'dart:async';

import 'package:flutter/services.dart';

import 'dart:ffi'; // For FFI
import 'dart:io'; // For Platform.isX

final DynamicLibrary nativeAddLib = Platform.isAndroid
    ? DynamicLibrary.open("libnative_add.so")
    : DynamicLibrary.process();

//分配空间 a *sizeof(char *)大小的内存
final Pointer<Uint16> Function(int a) creatCharPoint = nativeAddLib
    .lookup<NativeFunction<Pointer<Uint16> Function(Int32 a)>>("creatCharPoint")
    .asFunction();
// C string pointer return function - char *hello_world();
// There's no need for two typedefs here, as both the
// C and Dart functions have the same signature

// int16_t * Resample_s16(const int16_t *input, int16_t *output, int inSampleRate, int outSampleRate, uint64_t inputSize,
//     uint32_t channels
// ) {
//
// typedef resample_s16_func = Pointer<Uint16> Function(Pointer<Uint16> input,Pointer<Uint16> output, Int32 inSampleRate, Int32 outSampleRate,Int64 inputSize,Int32 channels);
// typedef Resample_s16 = Pointer<Uint16> Function(Pointer<Uint16> input,Pointer<Uint16> output, int inSampleRate, int outSampleRate,int inputSize,int channels);
// final resample_s16Pointer = nativeAddLib.lookup<NativeFunction<resample_s16_func>>('Resample_s16');
// final resample_s16 = resample_s16Pointer.asFunction<Resample_s16>();
// struct rs_data *resample_init(int in_rate, int out_rate, int buffer_size)
typedef resample_init_func = Pointer<Coordinate> Function(Int32 in_rate,Int32 out_rate, Int32 buffer_size);
typedef Resample_init = Pointer<Coordinate> Function(int in_rate, int out_rate,int buffer_size);
final resample_initPointer = nativeAddLib.lookup<NativeFunction<resample_init_func>>('resample_init');
final resample_init = resample_initPointer.asFunction<Resample_init>();
// int resample(struct rs_data *rs, short *in_buf, int in_buf_size, short *out_buf,
// int out_buf_size, int last);

typedef resample_func = Int32 Function(Pointer<Coordinate> rs,Pointer<Uint16> in_buf, Int32 in_buf_size,Pointer<Uint16> out_buf,Int32 out_buf_size, Int32 last);
typedef Resample = int Function(Pointer<Coordinate> rs, Pointer<Uint16> in_buf,int in_buf_size,Pointer<Uint16> out_buf,int out_buf_size, int last);
final resamplePointer = nativeAddLib.lookup<NativeFunction<resample_func>>('resample');
final resample = resamplePointer.asFunction<Resample>();

class Coordinate extends Struct{
  @Double()
  double factor;
  @Int32()
  int time;
  @Int16()
  int in_buf_ptr;
  @Int16()
  int out_buf_ptr;
  @Int16()
  int in_buf_read;
  @Int16()
  int in_buf_offset;
  @Int16()
  int in_buf_used;
  @Int16()
  int in_buf_size;
  @Int16()
  int out_buf_size;
  Pointer<Uint16> in_buf;
  Pointer<Uint16> out_buf;
}
class ResamplePlugin {
  static const MethodChannel _channel =
      const MethodChannel('resample_plugin');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }
}

==> resample_plugin-0.0.3.tar.gz: lib/resample_plugin.dart <==

import 'dart:async';

import 'package:flutter/services.dart';

import 'dart:ffi'; // For FFI
import 'dart:io'; // For Platform.isX

final DynamicLibrary nativeAddLib = Platform.isAndroid
    ? DynamicLibrary.open("libresample_plugin.so")
    : DynamicLibrary.process();

//分配空间 a *sizeof(char *)大小的内存
final Pointer<Uint16> Function(int a) creatCharPoint = nativeAddLib
    .lookup<NativeFunction<Pointer<Uint16> Function(Int32 a)>>("creatCharPoint")
    .asFunction();

final int Function(int x,int y) gettest = nativeAddLib
    .lookup<NativeFunction<Int32 Function(Int32 x,Int32 y)>>("gettest")
    .asFunction();
// C string pointer return function - char *hello_world();
// There's no need for two typedefs here, as both the
// C and Dart functions have the same signature

// int16_t * Resample_s16(const int16_t *input, int16_t *output, int inSampleRate, int outSampleRate, uint64_t inputSize,
//     uint32_t channels
// ) {
//
// typedef resample_s16_func = Pointer<Uint16> Function(Pointer<Uint16> input,Pointer<Uint16> output, Int32 inSampleRate, Int32 outSampleRate,Int64 inputSize,Int32 channels);
// typedef Resample_s16 = Pointer<Uint16> Function(Pointer<Uint16> input,Pointer<Uint16> output, int inSampleRate, int outSampleRate,int inputSize,int channels);
// final resample_s16Pointer = nativeAddLib.lookup<NativeFunction<resample_s16_func>>('Resample_s16');
// final resample_s16 = resample_s16Pointer.asFunction<Resample_s16>();
// struct rs_data *resample_init(int in_rate, int out_rate, int buffer_size)
typedef resample_init_func = Pointer<Coordinate> Function(Int32 in_rate,Int32 out_rate, Int32 buffer_size);
typedef Resample_init = Pointer<Coordinate> Function(int in_rate, int out_rate,int buffer_size);
final resample_initPointer = nativeAddLib.lookup<NativeFunction<resample_init_func>>('resample_init');
final resample_init = resample_initPointer.asFunction<Resample_init>();
// int resample(struct rs_data *rs, short *in_buf, int in_buf_size, short *out_buf,
// int out_buf_size, int last);

typedef resample_func = Int32 Function(Pointer<Coordinate> rs,Pointer<Uint16> in_buf, Int32 in_buf_size,Pointer<Uint16> out_buf,Int32 out_buf_size, Int32 last);
typedef Resample = int Function(Pointer<Coordinate> rs, Pointer<Uint16> in_buf,int in_buf_size,Pointer<Uint16> out_buf,int out_buf_size, int last);
final resamplePointer = nativeAddLib.lookup<NativeFunction<resample_func>>('resample');
final resample = resamplePointer.asFunction<Resample>();
// void resample_close(struct rs_data *rs)

typedef resample_close_func = Void Function(Pointer<Coordinate> rs);
typedef Resample_Close = void Function(Pointer<Coordinate> rs);
final resample_closePointer = nativeAddLib.lookup<NativeFunction<resample_close_func>>('resample_close');
final resample_close = resample_closePointer.asFunction<Resample_Close>();

class Coordinate extends Struct{
  @Double()
  double factor;
  @Int32()
  int time;
  @Int16()
  int in_buf_ptr;
  @Int16()
  int out_buf_ptr;
  @Int16()
  int in_buf_read;
  @Int16()
  int in_buf_offset;
  @Int16()
  int in_buf_used;
  @Int16()
  int in_buf_size;
  @Int16()
  int out_buf_size;
  Pointer<Uint16> in_buf;
  Pointer<Uint16> out_buf;
}
class ResamplePlugin {
  static const MethodChannel _channel =
      const MethodChannel('resample_plugin');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }
}
